@@ -17,6 +17,7 @@
 
 from __future__ import annotations
 
+import json
 import os
 import re
 from unittest import mock
@@ -31,12 +32,8 @@ from airflow.exceptions import AirflowException
 from airflow.models import Connection
 from airflow.providers.git.bundles.git import GitDagBundle
 from airflow.providers.git.hooks.git import GitHook
-from airflow.utils import db
 
 from tests_common.test_utils.config import conf_vars
-from tests_common.test_utils.db import clear_db_connections
-
-pytestmark = pytest.mark.db_test
 
 
 @pytest.fixture(autouse=True)
@@ -70,18 +67,23 @@ def git_repo(tmp_path_factory):
 class TestGitDagBundle:
     @classmethod
     def teardown_class(cls) -> None:
-        clear_db_connections()
+        return
 
-    @classmethod
-    def setup_class(cls) -> None:
-        db.merge_conn(
+    # TODO: Potential performance issue, converted setup_class to a setup_connections function level fixture
+    @pytest.fixture(autouse=True)
+    def setup_connections(self, create_connection_without_db, request):
+        # Skip setup for tests that need to create their own connections
+        if request.function.__name__ in ["test_view_url", "test_view_url_subdir"]:
+            return
+
+        create_connection_without_db(
             Connection(
                 conn_id="git_default",
                 host="git@github.com:apache/airflow.git",
                 conn_type="git",
             )
         )
-        db.merge_conn(
+        create_connection_without_db(
             Connection(
                 conn_id=CONN_HTTPS,
                 host=AIRFLOW_HTTPS_URL,
@@ -89,7 +91,7 @@ class TestGitDagBundle:
                 conn_type="git",
             )
         )
-        db.merge_conn(
+        create_connection_without_db(
             Connection(
                 conn_id=CONN_NO_REPO_URL,
                 conn_type="git",
@@ -115,17 +117,17 @@ class TestGitDagBundle:
             tracking_ref=GIT_DEFAULT_BRANCH,
             repo_url="https://github.com/apache/zzzairflow",
         )
-        assert bundle.repo_url == f"https://{ACCESS_TOKEN}@github.com/apache/zzzairflow"
+        assert bundle.repo_url == "https://github.com/apache/zzzairflow"
 
     def test_falls_back_to_connection_host_when_no_repo_url_provided(self):
-        bundle = GitDagBundle(name="test", tracking_ref=GIT_DEFAULT_BRANCH)
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref=GIT_DEFAULT_BRANCH)
         assert bundle.repo_url == bundle.hook.repo_url
 
     @mock.patch("airflow.providers.git.bundles.git.GitHook")
     def test_get_current_version(self, mock_githook, git_repo):
         repo_path, repo = git_repo
         mock_githook.return_value.repo_url = repo_path
-        bundle = GitDagBundle(name="test", tracking_ref=GIT_DEFAULT_BRANCH)
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref=GIT_DEFAULT_BRANCH)
 
         bundle.initialize()
 
@@ -146,6 +148,7 @@ class TestGitDagBundle:
 
         bundle = GitDagBundle(
             name="test",
+            git_conn_id=CONN_HTTPS,
             version=starting_commit.hexsha,
             tracking_ref=GIT_DEFAULT_BRANCH,
         )
@@ -174,6 +177,7 @@ class TestGitDagBundle:
 
         bundle = GitDagBundle(
             name="test",
+            git_conn_id=CONN_HTTPS,
             version="test",
             tracking_ref=GIT_DEFAULT_BRANCH,
         )
@@ -195,7 +199,7 @@ class TestGitDagBundle:
         repo.index.add([file_path])
         repo.index.commit("Another commit")
 
-        bundle = GitDagBundle(name="test", tracking_ref=GIT_DEFAULT_BRANCH)
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref=GIT_DEFAULT_BRANCH)
         bundle.initialize()
 
         assert bundle.get_current_version() != starting_commit.hexsha
@@ -221,7 +225,7 @@ class TestGitDagBundle:
             writer.set_value("user", "name", "Test User")
             writer.set_value("user", "email", "test@example.com")
 
-        bundle = GitDagBundle(name="test", tracking_ref=GIT_DEFAULT_BRANCH)
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref=GIT_DEFAULT_BRANCH)
         bundle.initialize()
 
         assert bundle.get_current_version() == starting_commit.hexsha
@@ -252,7 +256,7 @@ class TestGitDagBundle:
         # add tag
         repo.create_tag("test123")
 
-        bundle = GitDagBundle(name="test", tracking_ref="test123")
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref="test123")
         bundle.initialize()
         assert bundle.get_current_version() == starting_commit.hexsha
 
@@ -279,7 +283,7 @@ class TestGitDagBundle:
         mock_githook.return_value.repo_url = repo_path
 
         repo.create_head("test")
-        bundle = GitDagBundle(name="test", tracking_ref="test")
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref="test")
         bundle.initialize()
         assert bundle.repo.head.ref.name == "test"
 
@@ -289,6 +293,7 @@ class TestGitDagBundle:
         mock_githook.return_value.repo_url = repo_path
         bundle = GitDagBundle(
             name="test",
+            git_conn_id=CONN_HTTPS,
             version="not_found",
             tracking_ref=GIT_DEFAULT_BRANCH,
         )
@@ -313,6 +318,7 @@ class TestGitDagBundle:
 
         bundle = GitDagBundle(
             name="test",
+            git_conn_id=CONN_HTTPS,
             tracking_ref=GIT_DEFAULT_BRANCH,
             subdir=subdir,
         )
@@ -405,19 +411,110 @@ class TestGitDagBundle:
         ],
     )
     @mock.patch("airflow.providers.git.bundles.git.Repo")
-    def test_view_url(self, mock_gitrepo, repo_url, extra_conn_kwargs, expected_url, session):
-        session.query(Connection).delete()
-        conn = Connection(
-            conn_id="git_default",
-            host=repo_url,
-            conn_type="git",
-            **(extra_conn_kwargs or {}),
+    def test_view_url(
+        self, mock_gitrepo, repo_url, extra_conn_kwargs, expected_url, create_connection_without_db
+    ):
+        create_connection_without_db(
+            Connection(
+                conn_id="my_git_connection",
+                host=repo_url,
+                conn_type="git",
+                **(extra_conn_kwargs or {}),
+            )
+        )
+        bundle = GitDagBundle(
+            name="test",
+            git_conn_id="my_git_connection",
+            tracking_ref="main",
+        )
+        bundle.initialize = mock.MagicMock()
+        view_url = bundle.view_url("0f0f0f")
+        assert view_url == expected_url
+        bundle.initialize.assert_not_called()
+
+    @pytest.mark.parametrize(
+        "repo_url, extra_conn_kwargs, expected_url",
+        [
+            (
+                "git@github.com:apache/airflow.git",
+                None,
+                "https://github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            ("git@github.com:apache/airflow", None, "https://github.com/apache/airflow/tree/0f0f0f/subdir"),
+            (
+                "https://github.com/apache/airflow",
+                None,
+                "https://github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://github.com/apache/airflow.git",
+                None,
+                "https://github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "git@gitlab.com:apache/airflow.git",
+                None,
+                "https://gitlab.com/apache/airflow/-/tree/0f0f0f/subdir",
+            ),
+            (
+                "git@bitbucket.org:apache/airflow.git",
+                None,
+                "https://bitbucket.org/apache/airflow/src/0f0f0f/subdir",
+            ),
+            (
+                "git@myorg.github.com:apache/airflow.git",
+                None,
+                "https://myorg.github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://myorg.github.com/apache/airflow.git",
+                None,
+                "https://myorg.github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://github.com/apache/airflow",
+                {"password": "abc123"},
+                "https://github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://github.com/apache/airflow",
+                {"login": "abc123"},
+                "https://github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://github.com/apache/airflow",
+                {"login": "abc123", "password": "def456"},
+                "https://github.com/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://github.com:443/apache/airflow",
+                None,
+                "https://github.com:443/apache/airflow/tree/0f0f0f/subdir",
+            ),
+            (
+                "https://github.com:443/apache/airflow",
+                {"password": "abc123"},
+                "https://github.com:443/apache/airflow/tree/0f0f0f/subdir",
+            ),
+        ],
+    )
+    @mock.patch("airflow.providers.git.bundles.git.Repo")
+    def test_view_url_subdir(
+        self, mock_gitrepo, repo_url, extra_conn_kwargs, expected_url, create_connection_without_db
+    ):
+        create_connection_without_db(
+            Connection(
+                conn_id="git_default",
+                host=repo_url,
+                conn_type="git",
+                **(extra_conn_kwargs or {}),
+            )
         )
-        session.add(conn)
-        session.commit()
         bundle = GitDagBundle(
             name="test",
             tracking_ref="main",
+            subdir="subdir",
+            git_conn_id="git_default",
         )
         bundle.initialize = mock.MagicMock()
         view_url = bundle.view_url("0f0f0f")
@@ -440,7 +537,7 @@ class TestGitDagBundle:
 
         with mock.patch("airflow.providers.git.bundles.git.Repo.clone_from") as mock_clone:
             mock_clone.side_effect = GitCommandError("clone", "Simulated error")
-            bundle = GitDagBundle(name="test", tracking_ref="main")
+            bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref="main")
             with pytest.raises(
                 AirflowException,
                 match=re.escape("Error cloning repository"),
@@ -460,26 +557,48 @@ class TestGitDagBundle:
 
                 assert "Repository path: %s not found" in str(exc_info.value)
 
+    @pytest.mark.db_test
     @patch.dict(os.environ, {"AIRFLOW_CONN_MY_TEST_GIT": '{"host": "something"}'})
-    @pytest.mark.parametrize("conn_id, should_find", [("my_test_git", True), ("something-else", False)])
-    def test_repo_url_access_missing_connection_doesnt_error(self, conn_id, should_find):
+    @pytest.mark.parametrize(
+        "conn_id, expected_hook_type",
+        [("my_test_git", GitHook), ("something-else", type(None))],
+    )
+    def test_repo_url_access_missing_connection_doesnt_error(self, conn_id, expected_hook_type):
         bundle = GitDagBundle(
             name="testa",
             tracking_ref="main",
             git_conn_id=conn_id,
-            repo_url="some_repo_url",
         )
-        assert bundle.repo_url == "some_repo_url"
-        if should_find:
-            assert isinstance(bundle.hook, GitHook)
-        else:
-            assert not hasattr(bundle, "hook")
+        assert isinstance(bundle.hook, expected_hook_type)
 
     @mock.patch("airflow.providers.git.bundles.git.GitHook")
     def test_lock_used(self, mock_githook, git_repo):
         repo_path, repo = git_repo
         mock_githook.return_value.repo_url = repo_path
-        bundle = GitDagBundle(name="test", tracking_ref=GIT_DEFAULT_BRANCH)
+        bundle = GitDagBundle(name="test", git_conn_id=CONN_HTTPS, tracking_ref=GIT_DEFAULT_BRANCH)
         with mock.patch("airflow.providers.git.bundles.git.GitDagBundle.lock") as mock_lock:
             bundle.initialize()
             assert mock_lock.call_count == 2  # both initialize and refresh
+
+    @pytest.mark.parametrize(
+        "conn_json, repo_url, expected",
+        [
+            (
+                {"host": "git@github.com:apache/airflow.git"},
+                "git@github.com:apache/hello.git",
+                "git@github.com:apache/hello.git",
+            ),
+            ({"host": "git@github.com:apache/airflow.git"}, None, "git@github.com:apache/airflow.git"),
+            ({}, "git@github.com:apache/hello.git", "git@github.com:apache/hello.git"),
+        ],
+    )
+    def test_repo_url_precedence(self, conn_json, repo_url, expected):
+        conn_str = json.dumps(conn_json)
+        with patch.dict(os.environ, {"AIRFLOW_CONN_MY_TEST_GIT": conn_str}):
+            bundle = GitDagBundle(
+                name="test",
+                tracking_ref="main",
+                git_conn_id="my_test_git",
+                repo_url=repo_url,
+            )
+            assert bundle.repo_url == expected
